@@ -1,7 +1,7 @@
 /* 
- * This file is part of maemo-af-desktop
+ * This file is part of hildon-desktop
  *
- * Copyright (C) 2005, 2006 Nokia Corporation.
+ * Copyright (C) 2005, 2006, 2007 Nokia Corporation.
  *
  * Contact: Karoliina Salminen <karoliina.t.salminen@nokia.com>
  *
@@ -21,12 +21,24 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <signal.h>
 #include <X11/Xatom.h>
 #include <gdk/gdkx.h>
+
+#ifdef HAVE_LIBHILDON
+#include <hildon/hildon-defines.h>
+#include <hildon/hildon-banner.h>
+#include <hildon/hildon-note.h>
+#else
 #include <hildon-widgets/hildon-defines.h>
 #include <hildon-widgets/hildon-banner.h>
 #include <hildon-widgets/hildon-note.h>
+#endif
+
 
 #include "hd-wm-types.h"
 #include "hd-wm-memory.h"
